@@ -211,3 +211,52 @@ getRGtk2Version = function() {
   names(ver) <- c("major","minor","version")
   return(ver)
 }
+
+## Determin which OS
+##' is windows the OS?
+##'
+##' @return TRUE or FALSE
+isWindows <- function() {
+
+}
+
+##' is windows the OS?
+##'
+##' @return TRUE or FALSE
+isMac <- function() {
+
+}
+
+##' is windows the OS?
+##'
+##' @return TRUE or FALSE
+isUNIX <- function() {
+
+}
+
+
+## mouse click processing
+
+##' Return TRUE if first mouse click
+##'
+##' To be called from key-press|release-event
+##' @param e event for mouse press
+##' @return TRUE or FALSE
+isFirstMouseClick <- function(e) {
+  if(!is(e, "GdkEvent"))
+    stop("Must pass in an event")
+  e$getButton() == 1
+}
+
+##' Return TRUE/FALSE if right mouse click
+##'
+##' To be called from key-press|release-event
+##' @param e event for mouse press
+##' @return TRUE or FALSE
+isRightMouseClick <- function(e) {
+  if(!is(e, "GdkEvent"))
+    stop("Must pass in an event")
+  
+  e$GetButton() == 3 ||
+  (e$GetState() == GdkModifierType['control-mask'] && e$GetButton() == 1) 
+}
